0.9.9 API documentation: std_based_type.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

std_based_type.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18 #include <cstdlib>
19
20 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
21 # ifndef GLM_ENABLE_EXPERIMENTAL
22 # pragma message("GLM: GLM_GTX_std_based_type is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
23 # else
24 # pragma message("GLM: GLM_GTX_std_based_type extension included")
25 # endif
26 #endif
27
28 namespace glm
29 {
32
35 typedef vec<1, std::size_t, defaultp> size1;
36
39 typedef vec<2, std::size_t, defaultp> size2;
40
43 typedef vec<3, std::size_t, defaultp> size3;
44
47 typedef vec<4, std::size_t, defaultp> size4;
48
51 typedef vec<1, std::size_t, defaultp> size1_t;
52
55 typedef vec<2, std::size_t, defaultp> size2_t;
56
59 typedef vec<3, std::size_t, defaultp> size3_t;
60
63 typedef vec<4, std::size_t, defaultp> size4_t;
64
66 }//namespace glm
67
68 #include "std_based_type.inl"
glm::size1
vec< 1, std::size_t, defaultp > size1
Vector type based of one std::size_t component.
Definition: std_based_type.hpp:35
glm::size3_t
vec< 3, std::size_t, defaultp > size3_t
Vector type based of three std::size_t components.
Definition: std_based_type.hpp:59
glm::size2_t
vec< 2, std::size_t, defaultp > size2_t
Vector type based of two std::size_t components.
Definition: std_based_type.hpp:55
glm::size4
vec< 4, std::size_t, defaultp > size4
Vector type based of four std::size_t components.
Definition: std_based_type.hpp:47
glm::size1_t
vec< 1, std::size_t, defaultp > size1_t
Vector type based of one std::size_t component.
Definition: std_based_type.hpp:51
glm::size3
vec< 3, std::size_t, defaultp > size3
Vector type based of three std::size_t components.
Definition: std_based_type.hpp:43
glm::size2
vec< 2, std::size_t, defaultp > size2
Vector type based of two std::size_t components.
Definition: std_based_type.hpp:39
glm::size4_t
vec< 4, std::size_t, defaultp > size4_t
Vector type based of four std::size_t components.
Definition: std_based_type.hpp:63
glm
Definition: common.hpp:20